@@ -9,6 +9,7 @@ import pytz
 from croniter import croniter, CroniterBadDateError, CroniterBadCronError, CroniterNotAlphaError
 from croniter.tests import base
 from tzlocal import get_localzone
+import dateutil.tz
 
 
 class CroniterTest(base.TestCase):
@@ -650,6 +651,13 @@ class CroniterTest(base.TestCase):
         n2 = itr2.get_next(datetime)
         self.assertEqual(n2.tzinfo.zone, 'Asia/Tokyo')
 
+    def testTimezoneDateutil(self):
+        tokyo = dateutil.tz.gettz('Asia/Tokyo')
+        base = datetime(2013, 3, 4, 12, 15, tzinfo=tokyo)
+        itr = croniter('* * * * *', base)
+        n1 = itr.get_next(datetime)
+        self.assertEqual(n1.tzinfo.tzname(n1), 'JST')
+
     def testInitNoStartTime(self):
         itr = croniter('* * * * *')
         sleep(.01)
@@ -970,6 +978,36 @@ class CroniterTest(base.TestCase):
             "31 * * * *",
             datetime(2019, 1, 14, 1, 31, 0, 0)
         ))
+        self.assertTrue(croniter.match(
+            "0 0 10 * wed",
+            datetime(2020, 6, 10, 0, 0, 0, 0),
+            day_or=True
+        ))
+        self.assertTrue(croniter.match(
+            "0 0 10 * fri",
+            datetime(2020, 6, 10, 0, 0, 0, 0),
+            day_or=True
+        ))
+        self.assertTrue(croniter.match(
+            "0 0 10 * fri",
+            datetime(2020, 6, 12, 0, 0, 0, 0),
+            day_or=True
+        ))
+        self.assertTrue(croniter.match(
+            "0 0 10 * wed",
+            datetime(2020, 6, 10, 0, 0, 0, 0),
+            day_or=False
+        ))
+        self.assertFalse(croniter.match(
+            "0 0 10 * fri",
+            datetime(2020, 6, 10, 0, 0, 0, 0),
+            day_or=False
+        ))
+        self.assertFalse(croniter.match(
+            "0 0 10 * fri",
+            datetime(2020, 6, 12, 0, 0, 0, 0),
+            day_or=False
+        ))
 
 
     def test_dst_issue90_st31ny(self):
@@ -1018,7 +1056,7 @@ class CroniterTest(base.TestCase):
             itt.get_next(datetime).isoformat(),
             itt.get_next(datetime).isoformat(),
         ]
-        self.assertEqual(ret, [
+        self.assertEqual(rett, [
             '2020-03-30T02:01:00+02:00',
             '2020-03-29T01:01:00+01:00',
             '2020-03-28T03:01:00+01:00',
